Welcome to Poisson Approval's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   getting_started
   tutorials
   reference
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
